@@ -240,7 +240,10 @@ class ErrorHandler(utils.Cog):
             utils.errors.IsNotUpgradeChatSubscriber, utils.errors.IsNotVoter, utils.errors.NotBotSupport,
         )
         if isinstance(error, owner_reinvoke_errors) and ctx.original_author_id in self.bot.owner_ids:
-            return await ctx.reinvoke()
+            if self.bot.config.get("owners_ignore_check_failures", True) and isinstance(error, commands.CheckFailure):
+                pass
+            else:
+                return await ctx.reinvoke()
 
         # See if the command itself has an error handler AND it isn't a locally handlled arg
         # if hasattr(ctx.command, "on_error") and not isinstance(ctx.command, utils.Command):
@@ -281,7 +284,11 @@ class ErrorHandler(utils.Cog):
         # Ping unhandled errors to the owners and to the event webhook
         error_string = "".join(traceback.format_exception(None, error, error.__traceback__))
         file_handle = io.StringIO(error_string + "\n")
-        error_text = f"Error `{error}` encountered.\nGuild `{ctx.guild.id}`, channel `{ctx.channel.id}`, user `{ctx.author.id}`\n```\n{ctx.message.content}\n```"
+        guild_id = ctx.guild.id if ctx.guild else None
+        error_text = (
+            f"Error `{error}` encountered.\nGuild `{guild_id}`, channel `{ctx.channel.id}`, "
+            f"user `{ctx.author.id}`\n```\n{ctx.message.content}\n```"
+        )
 
         # DM to owners
         if self.bot.config.get('dm_uncaught_errors', False):
