@@ -1,7 +1,7 @@
 import re as _re
 from discord.ext import commands as _dpy_commands
 
-from . import checks, converters, errors, interactions  # Interactions is only here for backdating
+from . import checks, converters, errors, menus, interactions  # Interactions is only here for backdating
 from .checks import cooldown
 from .context_embed import Embed
 from .custom_bot import MinimalBot, Bot, ComponentMessage
@@ -12,7 +12,6 @@ from .database import DatabaseConnection
 from .redis import RedisConnection, RedisChannelHandler, redis_channel_handler
 from .statsd import StatsdConnection
 from .time_value import TimeValue
-from .settings_menu import SettingsMenu, SettingsMenuOption, SettingsMenuIterable, SettingsMenuConverter
 from .interactions import ApplicationCommand, ApplicationCommandOption, ApplicationCommandOptionChoice, ApplicationCommandOptionType
 from .upgrade_chat import (
     UpgradeChat, UpgradeChatOrder, UpgradeChatUser, UpgradeChatOrderItem, UpgradeChatInterval, UpgradeChatProduct,
@@ -20,6 +19,7 @@ from .upgrade_chat import (
 )
 from .paginator import Paginator
 from .interactions.components import *
+from .help_command import HelpCommand
 
 
 def command(*args, **kwargs):
