@@ -130,6 +130,9 @@ class MinimalBot(commands.AutoShardedBot):
         # Make sure we init the bot
         super().__init__(*args, **kwargs)
 
+        # Add some attrs that appear in a lot of places
+        self.application_id = None
+
         # Mess with the default D.py message send and edit methods
         async def send_button_msg_prop(messagable, *args, **kwargs) -> discord.Message:
             return await self._send_button_message(messagable, *args, **kwargs)
@@ -178,6 +181,18 @@ class MinimalBot(commands.AutoShardedBot):
         # discord.Message = ComponentMessage
         # discord.WebhookMessage = ComponentWebhookMessage
 
+    async def get_application_id(self) -> int:
+        """
+        Get the bot's application client ID.
+        """
+
+        if self.application_id:
+            return self.application_id
+        app = await self.application_info()
+        self.application_id = app.id
+        self._connection.application_id = app.id
+        return self.application_id
+
     async def create_message_log(
             self, messages: typing.Union[typing.List[discord.Message], discord.iterators.HistoryIterator]) -> str:
         """
@@ -372,14 +387,14 @@ class MinimalBot(commands.AutoShardedBot):
         )
         return await self.http.request(r)
 
-    async def get_context(self, message, *, cls=Context) -> 'discord.ext.commands.Context':
+    async def get_context(self, message, *, cls=None) -> 'discord.ext.commands.Context':
         """
         Create a new context object using the utils' Context.
 
         :meta private:
         """
 
-        return await super().get_context(message, cls=cls)
+        return await super().get_context(message, cls=cls or Context)
 
     def get_context_message(self, channel, content, embed, *args, **kwargs):
         """
@@ -400,7 +415,8 @@ class MinimalBot(commands.AutoShardedBot):
             components: MessageComponents = None,
             ephemeral: bool = False, embeddify: bool = None,
             image_url: bool = None, embeddify_file: bool = True,
-            wait: bool = True):
+            wait: bool = True,
+            embeds: typing.List[discord.Embed] = None):
         """
         An alternative send method so that we can add components to messages.
 
@@ -419,8 +435,14 @@ class MinimalBot(commands.AutoShardedBot):
 
         # Work out the main content
         content = str(content) if content is not None else None
-        if embed is not None:
-            embed = embed.to_dict()
+        if embed is not None and embeds is not None:
+            raise discord.InvalidArgument('cannot pass both embed and embeds parameter to send()')
+        if embed:
+            embeds = [embed]
+        if embeds and len(embeds) > 10:
+            raise discord.InvalidArgument('embeds parameter must be a list of up to 10 elements')
+        if embeds:
+            embeds = [embed.to_dict() for embed in embeds]
 
         # Work out our allowed mentions
         if allowed_mentions is not None:
@@ -486,11 +508,8 @@ class MinimalBot(commands.AutoShardedBot):
             payload['content'] = content
         if tts:
             payload['tts'] = True
-        if embed:
-            if r.path.startswith('/webhooks') or r.path.startswith('/interactions'):
-                payload['embeds'] = [embed]
-            else:
-                payload['embed'] = embed
+        if embeds:
+            payload['embeds'] = embeds
         if nonce:
             payload['nonce'] = nonce
         if allowed_mentions:
@@ -525,14 +544,14 @@ class MinimalBot(commands.AutoShardedBot):
                                 'filename': file.filename, 'content_type': 'application/octet-stream',
                             }
                         )
-                response_data = await self.http.request(r, form=form, files=files)
+                response_data = await messageable._state.http.request(r, form=form, files=files)
             finally:
                 for f in files:
                     f.close()
         else:
             if wait is False:
                 payload = {"type": 4, "data": payload.copy()}
-            response_data = await self.http.request(r, json=payload)
+            response_data = await messageable._state.http.request(r, json=payload)
 
         # Set the attributes for the interactions
         try:
@@ -581,18 +600,26 @@ class MinimalBot(commands.AutoShardedBot):
             if content is not None:
                 fields['content'] = str(content)
 
-        # Make the embeds
+        # Make the embed[s]
         try:
-            embed = fields['embed']
+            embed = fields.pop('embed')
         except KeyError:
-            pass
+            try:
+                embeds = fields.pop('embeds')
+            except KeyError:
+                pass
+            else:
+                if embeds is not None:
+                    embeds = [e.to_dict() for e in embeds]
+                else:
+                    embeds = []
+                fields['embeds'] = embeds
         else:
             if embed is not None:
-                if isinstance(message, discord.WebhookMessage):
-                    fields['embeds'] = [embed.to_dict()]
-                    fields.pop('embed')
-                else:
-                    fields['embed'] = embed.to_dict()
+                embeds = [embed.to_dict()]
+            else:
+                embeds = []
+            fields['embeds'] = embeds
 
         # Make the components
         try:
@@ -650,7 +677,7 @@ class MinimalBot(commands.AutoShardedBot):
                     app_id=message._state._webhook.id, token=message._state._webhook.token,
                     message_id=message.id,
                 )
-                response_data = await self.http.request(r, json=fields)
+                response_data = await message._state.http.request(r, json=fields)
             else:
                 response_data = await message._state.http.edit_message(message.channel.id, message.id, **fields)
             message._update(response_data)
@@ -759,9 +786,6 @@ class Bot(MinimalBot):
         # Aiohttp session
         self.session: aiohttp.ClientSession = aiohttp.ClientSession(loop=self.loop)
 
-        # Application ID (may not be bot ID)
-        self.application_id = None
-
         # Allow database connections like this
         self.database: DatabaseConnection = DatabaseConnection
         self.database.logger = self.logger.getChild('database')
@@ -1053,18 +1077,6 @@ class Bot(MinimalBot):
             self.logger.error(f"The webhook set in your config for the event {event_name} is not a valid Discord webhook")
             return None
 
-    async def get_application_id(self) -> int:
-        """
-        Get the bot's application client ID.
-        """
-
-        if self.application_id:
-            return self.application_id
-        app = await self.application_info()
-        self.application_id = app.id
-        self._connection.application_id = app.id
-        return self.application_id
-
     async def add_delete_reaction(
             self, message: discord.Message, valid_users: typing.List[discord.User] = None, *,
             delete: typing.List[discord.Message] = None, timeout: float = 60.0, wait: bool = False) -> None:
