@@ -102,13 +102,13 @@ class InteractionMessageable(Messageable):
         await self._state.http.request(r, json={"type": self.ACK_RESPONSE_TYPE, "data": {"flags": flags.value}})
         self._sent_ack_response = True
 
-    async def respond(self, *args, **kwargs):
+    def respond(self, *args, **kwargs):
         """
         Send a type 4 response to Discord for the interaction. The :func:`send` method does this for
         you automatically if you use the :code:`wait=False` kwarg.
         """
 
-        await self.send(*args, wait=False, **kwargs)
+        self._state.loop.create_task(self.send(*args, wait=False, **kwargs))
 
     def typing(self, *args, **kwargs):
         return InteractionTyping(self)
