@@ -5,6 +5,12 @@ import discord
 from discord.ext import commands
 
 from .errors import InvokedMetaCommand
+from .interactions.components.action_row import MessageComponents, ActionRow
+from .interactions.components.buttons import Button, ButtonStyle
+
+
+def do_nothing(value):
+    return value
 
 
 class SettingsMenuError(commands.CommandError):
@@ -57,7 +63,6 @@ class SettingsMenuOption(object):
         self._display: typing.Union[str, typing.Callable[[commands.Context], str]] = display
         self.converter_args: typing.List[SettingsMenuConverter] = converter_args or list()
         self.callback: typing.Callable[['SettingsMenuOption', typing.List[typing.Any]], None] = callback
-        self.emoji: str = emoji
         self.allow_nullable: bool = allow_nullable
 
     def get_display(self) -> str:
@@ -74,7 +79,7 @@ class SettingsMenuOption(object):
 
     async def perform_action(self) -> None:
         """
-        Performs the stored action using the given args and kwargs.
+        Runs through the converters before calling the instance's callback method with the converted data.
         """
 
         # Get data
@@ -93,6 +98,8 @@ class SettingsMenuOption(object):
         # Do callback
         if isinstance(self.callback, commands.Command):
             await self.callback.invoke(self.context)
+        elif isinstasnce(self.callback, SettingsMenu):
+            await self.callback.start(self.context)
         else:
             called_data = self.callback(self, *returned_data)
             if asyncio.iscoroutine(called_data):
@@ -123,18 +130,29 @@ class SettingsMenuOption(object):
         """
 
         # Send prompt
-        bot_message = await self.context.send(prompt)
+        components = None
         if reactions:
-            for r in reactions:
-                self.context.bot.loop.create_task(bot_message.add_reaction(r))
+            components = MessageComponents(*[ActionRow(emoji=i, custom_id=i) for i in reactions])
+        bot_message = await self.context.send(prompt, components=components)
+
+        # Wait for a response from the user
+        user_message = None
         try:
             if reactions:
-                user_message = None
-                check = lambda p: p.message_id == bot_message.id and p.user_id == self.context.author.id and str(p.emoji) in reactions
-                reaction = await self.context.bot.wait_for("raw_reaction_add", timeout=120, check=check)
-                content = str(reaction.emoji)
+                def check(payload):
+                    return all([
+                        payload.message.id == bot_message.id,
+                        payload.user.id == self.context.author.id,
+                    ])
+                payload = await self.context.bot.wait_for("component_interaction", timeout=120, check=check)
+                await payload.ack()
+                content = str(payload.component.custom_id)
             else:
-                check = lambda m: m.channel.id == self.context.channel.id and m.author.id == self.context.author.id
+                def check(message):
+                    return all([
+                        message.channel.id == self.context.channel.id,
+                        message.author.id == self.context.author.id,
+                    ])
                 user_message = await self.context.bot.wait_for("message", timeout=120, check=check)
                 content = user_message.content
         except asyncio.TimeoutError:
@@ -277,7 +295,7 @@ class SettingsMenuOption(object):
             column_name (str): The name of the column that the data should be inserted into.
                 This is the same name that's used for caching. This should NOT be a user supplied value.
             serialize_function (typing.Callable[[typing.Any], typing.Any], optional): The function that is called to convert the
-                input data in the callback into a database-friendly value. This is _not_ called for caching the value, only
+                input data in the callback into a database-friendly value. This is *not* called for caching the value, only
                 for databasing. The default serialize function doesn't do anything, but is provided so you don't have to provide
                 one yourself.
 
@@ -286,7 +304,7 @@ class SettingsMenuOption(object):
         """
 
         if serialize_function is None:
-            serialize_function = lambda x: x
+            serialize_function = do_nothing
         return cls.get_set_settings_callback(table_name, "guild_id", column_name, serialize_function)
 
     @classmethod
@@ -305,7 +323,7 @@ class SettingsMenuOption(object):
             column_name (str): The name of the column that the data should be inserted into. This is the same name that's used for
                 caching the value. This should NOT be a user supplied value.
             serialize_function (typing.Callable[[typing.Any], typing.Any], optional): The function that is called to convert the input data
-                in the callback into a database-friendly value. This is _not_ called for caching the value, only for databasing. The default
+                in the callback into a database-friendly value. This is *not* called for caching the value, only for databasing. The default
                 serialize function doesn't do anything, but is provided so you don't have to provide one yourself.
 
         Returns:
@@ -313,7 +331,7 @@ class SettingsMenuOption(object):
         """
 
         if serialize_function is None:
-            serialize_function = lambda x: x
+            serialize_function = do_nothing
         return cls.get_set_settings_callback(table_name, "user_id", column_name, serialize_function)
 
     @staticmethod
@@ -327,12 +345,12 @@ class SettingsMenuOption(object):
         Args:
             table_name (str): The name of the table the data should be inserted into. This is not used when caching information.
                 This should NOT be a user supplied value.
-            primary_key (str): The primary key of the table that you want to insert to. This _only_ supports single primary keys and not
+            primary_key (str): The primary key of the table that you want to insert to. This *only* supports single primary keys and not
                 compound ones.
             column_name (str): The name of the column that the data should be inserted into. This is the same name that's used for
                 caching the value. This should NOT be a user supplied value.
             serialize_function (typing.Callable[[typing.Any], typing.Any], optional): The function that is called to convert the input data
-                in the callback into a database-friendly value. This is _not_ called for caching the value, only for databasing. The default
+                in the callback into a database-friendly value. This is *not* called for caching the value, only for databasing. The default
                 serialize function doesn't do anything, but is provided so you don't have to provide one yourself.
 
         Returns:
@@ -441,7 +459,7 @@ class SettingsMenuOption(object):
         """
 
         if serialize_function is None:
-            serialize_function = lambda x: x
+            serialize_function = do_nothing
 
         def wrapper(menu, ctx):
             """
@@ -548,8 +566,6 @@ class SettingsMenu(object):
                 await ctx.send("Done setting up!")
             except voxelbotutils.errors.InvokedMetaCommand:
                 pass
-
-
     """
 
     TICK_EMOJI = "\N{HEAVY CHECK MARK}"
@@ -579,26 +595,13 @@ class SettingsMenu(object):
 
         self.options.extend(option)
 
-    def bulk_add_options(self, ctx: commands.Context, *args):
-        """
-        :meta private: (deprecated)
-
-        Add multiple options to the settings list. Each option is simply thrown into a SettingsMenuOption item
-        and then added to the options list.
-        """
-
-        for data in args:
-            self.add_option(SettingsMenuOption(ctx, **data))
-
-    async def start(self, ctx: commands.Context, *, timeout: float = 120, clear_reactions_on_loop: bool = False):
+    async def start(self, ctx: commands.Context, *, timeout: float = 120):
         """
         Starts the menu running.
 
         Args:
             ctx (commands.Context): The context object for the called command.
             timeout (float, optional): How long the bot should wait for a reaction.
-            clear_reactions_on_loop (bool, optional): Exactly as it says - when the menu loops,
-                should reactions be cleared? You only need to set this to True if the items in a menu change on loop.
         """
 
         message = None
@@ -607,23 +610,23 @@ class SettingsMenu(object):
             # Send message
             self.emoji_options.clear()
             data, emoji_list = self.get_sendable_data(ctx)
-            sent_new_message = False
             if message is None:
                 message = await ctx.send(**data)
-                sent_new_message = True
             else:
                 await message.edit(**data)
-            if sent_new_message or clear_reactions_on_loop:
-                for e in emoji_list:
-                    ctx.bot.loop.create_task(message.add_reaction(e))
 
             # Get the reaction
             try:
-                check = lambda r, u: u.id == ctx.author.id and r.message.id == message.id
-                reaction, _ = await ctx.bot.wait_for("reaction_add", check=check, timeout=timeout)
+                def check(payload):
+                    return all([
+                        payload.message.id == message.id,
+                        payload.user.id == ctx.author.id,
+                    ])
+                payload = await ctx.bot.wait_for("component_interaction", check=check, timeout=timeout)
+                await payload.ack()
             except asyncio.TimeoutError:
                 break
-            picked_emoji = str(reaction.emoji)
+            picked_emoji = str(payload.component.custom_id)
 
             # Get the picked option
             try:
@@ -639,17 +642,6 @@ class SettingsMenu(object):
             except SettingsMenuError:
                 pass
 
-            # Remove the emoji
-            try:
-                if clear_reactions_on_loop:
-                    await reaction.message.clear_reactions()
-                else:
-                    await reaction.message.remove_reaction(picked_emoji, ctx.author)
-            except discord.Forbidden:
-                pass
-            except discord.NotFound:
-                break
-
         # Delete all the processing stuff
         try:
             await message.delete()
@@ -679,11 +671,11 @@ class SettingsMenu(object):
         for index, i in enumerate(self.options):
             emoji = i.emoji
             if emoji is None:
-                emoji = f"{index}\N{COMBINING ENCLOSING KEYCAP}"
+                emoji = f"{index}"
                 index += 1
             display = i.get_display()
             if display:
-                lines.append(f"{emoji} {i.get_display()}")
+                lines.append(f"{emoji}) {i.get_display()}")
             self.emoji_options[emoji] = i
             emoji_list.append(emoji)
 
@@ -695,8 +687,11 @@ class SettingsMenu(object):
         self.emoji_options[self.TICK_EMOJI] = None
         emoji_list.append(self.TICK_EMOJI)
 
+        buttons = [Button(emoji=i, custom_id=i) for i in emoji_list] + [Button("Done", "done", style=ButtonStyle.SUCCESS)]
+        components = MessageComponents.add_buttons_with_rows(*buttons)
+
         # Return data
-        return {'embed': embed}, emoji_list
+        return {'embed': embed, "components": components}, emoji_list
 
 
 class SettingsMenuIterable(SettingsMenu):
