@@ -430,14 +430,31 @@ def run_website(args: argparse.Namespace) -> None:
             '(?:<|(?:&lt;))@!?(?P<userid>\\d{16,23})(?:>|(?:&gt;))',
             lambda g: f'<span class="chatlog__mention">@{get_display_name(g)}</span>',
             string,
-            re.IGNORECASE | re.MULTILINE
+            string,
+            re.IGNORECASE | re.MULTILINE,
         )
+
+    def display_emojis(string):
+        def get_html(group):
+            return (
+                f'<img class="discord_emoji" src="https://cdn.discordapp.com/emojis/{group.group("id")}'
+                f'.{"gif" if group.group("animated") else "png"}" alt="Discord custom emoji: '
+                f'{group.group("name")}" style="height: 1em; width: auto;">'
+            )
+        return re.sub(
+            r"(?P<emoji>(?:<|&lt;)(?P<animated>a)?:(?P<name>\w+):(?P<id>\d+)(?:>|&gt;))",
+            get_html,
+            string,
+            re.IGNORECASE | re.MULTILINE,
+        )
+
     jinja_env.filters['regex_replace'] = regex_replace
     jinja_env.filters['escape_text'] = escape_text
     jinja_env.filters['timestamp'] = timestamp
     jinja_env.filters['int_to_hex'] = int_to_hex
     jinja_env.filters['markdown'] = to_markdown
     jinja_env.filters['display_mentions'] = display_mentions
+    jinja_env.filters['display_emojis'] = display_emojis
 
     # Add our connections and their loggers
     app['database'] = DatabaseConnection
